@@ -9,6 +9,7 @@ The majority of the "work" is defined in utils.py.
 import platform
 from functools import partial
 from operator import itemgetter
+from pathlib import PurePath
 from typing import (
     Any,
     Callable,
@@ -287,6 +288,8 @@ def natsorted(
         ['num2', 'num3', 'num5']
 
     """
+    if alg & ns.PRESORT:
+        seq = sorted(seq, reverse=reverse, key=str)
     return sorted(seq, reverse=reverse, key=natsort_keygen(key, alg))
 
 
@@ -476,6 +479,8 @@ def index_natsorted(
 
     # Pair the index and sequence together, then sort by element
     index_seq_pair = [(x, y) for x, y in enumerate(seq)]
+    if alg & ns.PRESORT:
+        index_seq_pair.sort(reverse=reverse, key=lambda x: str(itemgetter(1)(x)))
     index_seq_pair.sort(reverse=reverse, key=natsort_keygen(newkey, alg))
     return [x for x, _ in index_seq_pair]
 
@@ -665,16 +670,17 @@ def numeric_regex_chooser(alg: NSType) -> str:
 
 
 def _split_apply(
-    v: Any, key: Optional[Callable[[T], NatsortInType]] = None
+    v: Any, key: Optional[Callable[[T], NatsortInType]] = None, treat_base: bool = True
 ) -> Iterator[str]:
     if key is not None:
         v = key(v)
-    return utils.path_splitter(str(v))
+    if not isinstance(v, (str, PurePath)):
+        v = str(v)
+    return utils.path_splitter(v, treat_base=treat_base)
 
 
 # Choose the implementation based on the host OS
 if platform.system() == "Windows":
-
     from ctypes import wintypes, windll  # type: ignore
     from functools import cmp_to_key
 
@@ -688,11 +694,10 @@ if platform.system() == "Windows":
     ) -> Callable[[Any], NatsortOutType]:
         return cast(
             Callable[[Any], NatsortOutType],
-            lambda x: tuple(map(_winsort_key, _split_apply(x, key))),
+            lambda x: tuple(map(_winsort_key, _split_apply(x, key, treat_base=False))),
         )
 
 else:
-
     # For UNIX-based platforms, ICU performs MUCH better than locale
     # at replicating the file explorer's sort order. We will use
     # ICU's ability to do basic natural sorting as it also better
@@ -767,6 +772,7 @@ def os_sorted(
     seq: Iterable[T],
     key: Optional[Callable[[T], NatsortInType]] = None,
     reverse: bool = False,
+    presort: bool = False,
 ) -> List[T]:
     """
     Sort elements in the same order as your operating system's file browser
@@ -809,6 +815,10 @@ def os_sorted(
         Return the list in reversed sorted order. The default is
         `False`.
 
+    presort : {{True, False}}, optional
+        Equivalent to adding ``ns.PRESORT``, see :class:`ns` for
+        documentation. The default is `False`.
+
     Returns
     -------
     out : list
@@ -824,4 +834,6 @@ def os_sorted(
     This will implicitly coerce all inputs to str before collating.
 
     """
-    return sorted(seq, key=os_sort_keygen(key), reverse=reverse)
+    if presort:
+        seq = sorted(seq, reverse=reverse, key=str)
+    return sorted(seq, reverse=reverse, key=os_sort_keygen(key))
